Method: Nimbus::Tree#build_node
- Defined in:
- lib/nimbus/tree.rb
#build_node(individuals_ids, y_hat) ⇒ Object
Creates a node by taking a random sample of the SNPs and computing the loss function for every split by SNP of that sample.
43 44 |
# File 'lib/nimbus/tree.rb', line 43 def build_node(individuals_ids, y_hat) end |